@@ -19,14 +19,14 @@
 #ifndef __GOA_DAEMON_H__
 #define __GOA_DAEMON_H__
 
-#include <glib-object.h>
+#include <gio/gio.h>
 
 G_BEGIN_DECLS
 
 #define GOA_TYPE_DAEMON  (goa_daemon_get_type ())
 G_DECLARE_FINAL_TYPE (GoaDaemon, goa_daemon, GOA, DAEMON, GObject);
 
-GoaDaemon          *goa_daemon_new                (void);
+GoaDaemon          *goa_daemon_new                (GDBusConnection *connection);
 
 G_END_DECLS
 
