@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2011, 2012, 2015 Red Hat, Inc.
+ * Copyright © 2011 – 2017 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -21,7 +21,6 @@
 
 #include "goaclient.h"
 #include "goaerror.h"
-#include "goa-generated.h"
 
 G_LOCK_DEFINE_STATIC (init_lock);
 
@@ -50,15 +49,6 @@ struct _GoaClient
   GDBusObjectManager *object_manager;
 };
 
-typedef struct
-{
-  GObjectClass parent_class;
-
-  void (*account_added) (GoaClient *self, GDBusObject *object);
-  void (*account_removed) (GoaClient *self, GDBusObject *object);
-  void (*account_changed) (GoaClient *self, GDBusObject *object);
-} GoaClientClass;
-
 enum
 {
   PROP_0,
@@ -192,7 +182,7 @@ goa_client_class_init (GoaClientClass *klass)
     g_signal_new ("account-added",
                   G_TYPE_FROM_CLASS (klass),
                   G_SIGNAL_RUN_LAST,
-                  G_STRUCT_OFFSET (GoaClientClass, account_added),
+                  0,
                   NULL,
                   NULL,
                   g_cclosure_marshal_VOID__OBJECT,
@@ -211,7 +201,7 @@ goa_client_class_init (GoaClientClass *klass)
     g_signal_new ("account-removed",
                   G_TYPE_FROM_CLASS (klass),
                   G_SIGNAL_RUN_LAST,
-                  G_STRUCT_OFFSET (GoaClientClass, account_removed),
+                  0,
                   NULL,
                   NULL,
                   g_cclosure_marshal_VOID__OBJECT,
@@ -230,7 +220,7 @@ goa_client_class_init (GoaClientClass *klass)
     g_signal_new ("account-changed",
                   G_TYPE_FROM_CLASS (klass),
                   G_SIGNAL_RUN_LAST,
-                  G_STRUCT_OFFSET (GoaClientClass, account_changed),
+                  0,
                   NULL,
                   NULL,
                   g_cclosure_marshal_VOID__OBJECT,
