@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2012, 2013, 2014 Red Hat, Inc.
+ * Copyright © 2012 – 2017 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -37,13 +37,6 @@ struct _GoaEwsClient
   GObject parent_instance;
 };
 
-typedef struct _GoaEwsClientClass GoaEwsClientClass;
-
-struct _GoaEwsClientClass
-{
-  GObjectClass parent_class;
-};
-
 G_DEFINE_TYPE (GoaEwsClient, goa_ews_client, G_TYPE_OBJECT);
 
 /* ---------------------------------------------------------------------------------------------------- */
@@ -253,7 +246,7 @@ ews_client_autodiscover_response_cb (SoupSession *session, SoupMessage *msg, gpo
                    GOA_ERROR,
                    GOA_ERROR_FAILED, /* TODO: more specific */
                    /* Translators: the parameter is an XML element name. */
-                   _("Failed to find ‘%s’ element"), "Autodiscover");
+                   _("Failed to find “%s” element"), "Autodiscover");
       goto out;
     }
 
@@ -268,7 +261,7 @@ ews_client_autodiscover_response_cb (SoupSession *session, SoupMessage *msg, gpo
                    GOA_ERROR,
                    GOA_ERROR_FAILED, /* TODO: more specific */
                    /* Translators: the parameter is an XML element name. */
-                   _("Failed to find ‘%s’ element"), "Response");
+                   _("Failed to find “%s” element"), "Response");
       goto out;
     }
 
@@ -283,7 +276,7 @@ ews_client_autodiscover_response_cb (SoupSession *session, SoupMessage *msg, gpo
                    GOA_ERROR,
                    GOA_ERROR_FAILED, /* TODO: more specific */
                    /* Translators: the parameter is an XML element name. */
-                   _("Failed to find ‘%s’ element"), "Account");
+                   _("Failed to find “%s” element"), "Account");
       goto out;
     }
 
